[PATCH] nfs-utils: tests: Skip test if /dev/log is missing

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



From: Ben Hutchings <benh@xxxxxxxxxx>

Some build environments don't have a /dev/log, without which
the daemons will fail to run.

* Add a check_dev_log function to skip a test if it's missing
* Call it in t0001-statd-basic-mon-unmon.sh

Signed-off-by: Ben Hutchings <benh@xxxxxxxxxx>
Signed-off-by: Salvatore Bonaccorso <carnil@xxxxxxxxxx>
---
 tests/t0001-statd-basic-mon-unmon.sh | 3 ++-
 tests/test-lib.sh                    | 9 +++++++++
 2 files changed, 11 insertions(+), 1 deletion(-)

diff --git a/tests/test-lib.sh b/tests/test-lib.sh
index e47ad13539ac..b62ac2a6db4d 100644
--- a/tests/test-lib.sh
+++ b/tests/test-lib.sh
@@ -37,6 +37,15 @@ check_root() {
 	fi
 }
 
+# Most tests require /dev/log. Skip the test if it doesn't exist in this
+# environment.
+check_dev_log() {
+	if ! [ -e /dev/log ]; then
+		echo "*** Skipping this tests as it requires /dev/log ***"
+		exit 77
+	fi
+}
+
 # is lockd registered as a service?
 lockd_registered() {
 	rpcinfo -p | grep -q nlockmgr
diff --git a/tests/t0001-statd-basic-mon-unmon.sh b/tests/t0001-statd-basic-mon-unmon.sh
index 92517a144851..e1065e766ccc 100755
--- a/tests/t0001-statd-basic-mon-unmon.sh
+++ b/tests/t0001-statd-basic-mon-unmon.sh
@@ -21,8 +21,9 @@
 
 . ./test-lib.sh
 
 # This test needs root privileges
 check_root
+check_dev_log
 
 start_statd
 if [ $? -ne 0 ]; then
@@ -21,8 +21,9 @@
 . ./test-lib.sh
 
-# This test needs root privileges
+# This test needs root privileges and /dev/log
 check_root
-- 
2.34.1




[Index of Archives]     [Linux Filesystem Development]     [Linux USB Development]     [Linux Media Development]     [Video for Linux]     [Linux NILFS]     [Linux Audio Users]     [Yosemite Info]     [Linux SCSI]

  Powered by Linux